@@ -33,6 +33,9 @@ struct st_mod_sc_ssl {
 	const char *(*sc_ssl_get_version) ( sc_t *socket );
 	/* since version 1.2 */
 	int (*sc_ssl_starttls) ( sc_t *socket );
+	/* since version 1.3 */
+	int (*sc_ssl_set_ssl_method) ( sc_t *socket, const char *name );
+	int (*sc_ssl_set_cipher_list) ( sc_t *socket, const char *str );
 };
 
 #endif /* _MOD_SC_SSL_H_ */
